<?php
// class IziTranslate
// http://blog.niap3d.com/fr/1,10,news-45-Internationaliser-un-site-partie-2-.html
class IziTranslate{
	protected $txt = array();
	protected $langLst = array();
	protected $langRef = '';
	protected $lang = '';
	protected $pathLang = '';
	protected $debugMode = 0;
	//
	// constructeur
	//
	// argument :
	//		$aPath = chemin vers le dossier qui contient les sous dossiers de langues
	//
	function __construct($aPath){
		$this->pathLang = $aPath;
	}
	//
	// ajoute une langue
	//
	// argument :
	//		$aId = identifiant de la langue. l'identifiant est aussi le nom du dossier qui contient les textes
	//		$aName = nom de la langue [facultatif]
	//
	public function AddLanguage($aId, $aName=''){
		// vérifie si la langue est déjà enregistré
		if(isset($this->langLst[$aId]) || empty($aId)) return 0;
		// enregistre la langue et son nom
		$this->langLst[$aId] = $aName;
		$this->txt[$aId] = array();
		// défini la langue en cours si ce n'est pas déjà fait
		if($this->lang=='') $this->lang = $aId;
		// défini la langue de référence si ce n'est pas déjà fait
		if($this->langRef=='') $this->langRef = $aId;
		return 1;
	}
	//
	// définit la langue en cours
	//
	// argument :
	//		$aId = identifiant de la langue
	//
	public function SetLanguage($aId){
		// vérifie si la langue est déjà enregistré
		if(!empty($this->langLst[$aId])) return 0;
		$this->lang = $aId;
		return 1;
	}
	//
	// charge un fichier dans toutes les langues
	//
	// argument :
	//		$aPath = fichier à charger
	//
	public function LoadTxt($aPath){
		foreach($this->langLst as $k=>$v){
			$p = $this->pathLang.'/'.$k.'/'.$aPath;
			// verifie si le fichier existe
			if(file_exists($p)){
				// charge le fichier au format JSON, le décode et l'intégre aux texte déjà chargés
				$this->txt[$k] = array_merge($this->txt[$k], json_decode(file_get_contents($p), true));
			}
		}
		return 1;
	}
	//
	// définit la langue de référence
	//
	// argument :
	//		$aId = identifiant de la langue
	//
	public function SetRefLanguage($aId){
		// vérifie si la langue existe
		if(empty($this->langLst[$aId])) return 0;
		// enregistre
		$this->langRef = $aId;
		return 1;
	}
	//
	// renvoi un texte
	//
	// argument :
	//		$aId = identifiant du texte
	//		$aReplace = tableau de remplacement
	//
	public function GetTxt($aId, $aReplace=''){
		// renvoi un texte dans la langue en cours
		// si le texte n'existe pas dans la langue en cours,
		// la class essaye de le renvoyer dans la langue de référence
		$r = (empty($this->txt[$this->lang][$aId]) ? $this->txt[$this->langRef][$aId]:$this->txt[$this->lang][$aId]);
		if(empty($r)){
			// si le texte n'existe pas non plus dans la langue de référence
			// et que le mode debug est activé, renvoi un texte d'erreur
			if($this->debugMode) $r = '[KEY NOT FOUND : '.$aId.']';
			
		}else if(isset($aReplace)){
			// il y a des valeurs de remplacement
			// la fonction accepte un tableau (array) ou un texte (string)
			// génère le tableau ou le texte à rechercher
			if(is_array($aReplace)){
				$nb = count($aReplace);
				$s = array();
				for($i=1; $i<=$nb; $i++){
					$s[] = '%'.$i.'%';
				}
			}else $s = '%1%';
			$r = str_replace($s, $aReplace, $r);
		}
		return $r;
	}
	//
	// active le mode debug
	//
	public function DebutModeActive(){
		$this->debugMode = 1;
	}
}
?>